@@ -14,7 +14,7 @@ test_that("mof table has expected columns", {
   skip_on_cran()
   records <- occurrence(scientificname = species_mof, mof = TRUE)
   expect_true("mof" %in% names(records))
-  m <- measurements(records)
+  m <- unnest_extension(records, extension = "MeasurementOrFact")
   expect_true(is.data.frame(m))
   expect_true(all(c("measurementType", "measurementValue") %in% names(m)))
 })
@@ -22,7 +22,7 @@ test_that("mof table has expected columns", {
 test_that("measurements on dataframe with mof column returns dataframe", {
   skip_on_cran()
   records <- occurrence(scientificname = species_nomof, mof = TRUE)
-  m <- measurements(records)
+  m <- unnest_extension(records, extension = "MeasurementOrFact")
   expect_true(is.data.frame(m))
 })
 
@@ -30,7 +30,7 @@ test_that("measurements on dataframe without mof column returns NULL", {
   skip_on_cran()
   records <- occurrence(scientificname = species_nomof, mof = FALSE)
   suppressWarnings({
-    m <- measurements(records)
+    m <- unnest_extension(records, extension = "MeasurementOrFact")
   })
   expect_true(is.null(m))
 })
